@@ -4,16 +4,17 @@
 """Configurator"""
 
 
-import ConfigParser
 import logging
 import os
 
+from six.moves import configparser
+
+from imap_cli import const
+
 
 app_name = os.path.splitext(os.path.basename(__file__))[0]
 log = logging.getLogger(app_name)
 
-DEFAULT_CONFIG_FILE = '~/.config/imap-cli'
-
 
 class Ctx(object):
     # Account
@@ -30,10 +31,10 @@ class Ctx(object):
 def new_context_from_file(config_filename=None):
     ctx = Ctx()
     if config_filename is None:
-        config_filename = DEFAULT_CONFIG_FILE
+        config_filename = const.DEFAULT_CONFIG_FILE
     config_filename = os.path.abspath(os.path.expanduser(os.path.expandvars(config_filename)))
 
-    config = ConfigParser.RawConfigParser()
+    config = configparser.RawConfigParser()
     config.read(config_filename)
     log.debug("Reading configuration file '{}'".format(config_filename))
 
@@ -47,17 +48,11 @@ def new_context_from_file(config_filename=None):
     if config.has_option('display', 'limit'):
         ctx.limit = config.getint('display', 'limit')
 
-    ctx.format_status = config.get(
-        'display',
-        'format_status',
-        ) \
+    ctx.format_status = config.get('display', 'format_status') \
         if config.has_option('display', 'format_status') \
         else u'{directory}:{unseen} Unseen - {count} Mails - {recent} Recent'
 
-    ctx.format_list = config.get(
-        'display',
-        'format_list',
-        ) \
+    ctx.format_list = config.get('display', 'format_list') \
         if config.has_option('display', 'format_list') \
         else u'From: {mail_from:<30} To: {to:<20} Subjetc: {subject}'
     return ctx
